@@ -14,6 +14,10 @@ sub new {
     return $self;
 }
 
+sub key {
+    $_[0][1];
+}
+
 sub DESTROY {
     my $self = shift;
     my ( $hash, $key ) = splice @$self;
@@ -25,6 +29,7 @@ sub dismiss {
     @$self = ();
 }
 
+
 __PACKAGE__
 
 __END__
