@@ -1,6 +1,8 @@
 package KiokuDB::TypeMap::Entry::JSON::Scalar;
 use Moose;
 
+no warnings 'recursion';
+
 use namespace::clean -except => 'meta';
 
 with qw(KiokuDB::TypeMap::Entry::Std);
@@ -37,6 +39,18 @@ sub compile_expand {
     }
 }
 
+sub compile_refresh {
+    my ( $self, $class, @args ) = @_;
+
+    return sub {
+        my ( $linker, $scalar, $entry ) = @_;
+
+        $linker->inflate_data($entry->data, $scalar );
+
+        return $scalar;
+    };
+}
+
 __PACKAGE__->meta->make_immutable;
 
 __PACKAGE__
